/*
# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  
*/

/*=========================================================================
Program:   bbtk
Module:    $RCSfile$
Language:  C++
Date:      $Date$
Version:   $Revision$
=========================================================================*/

/* ---------------------------------------------------------------------

* Copyright (c) CREATIS-LRMN (Centre de Recherche en Imagerie Medicale)
* Authors : Eduardo Davila, Laurent Guigues, Jean-Pierre Roux
*
*  This software is governed by the CeCILL-B license under French law and
*  abiding by the rules of distribution of free software. You can  use,
*  modify and/ or redistribute the software under the terms of the CeCILL-B
*  license as circulated by CEA, CNRS and INRIA at the following URL
*  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
*  or in the file LICENSE.txt.
*
*  As a counterpart to the access to the source code and  rights to copy,
*  modify and redistribute granted by the license, users are provided only
*  with a limited warranty  and the software's author,  the holder of the
*  economic rights,  and the successive licensors  have only  limited
*  liability.
*
*  The fact that you are presently reading this means that you have had
*  knowledge of the CeCILL-B license and that you accept its terms.
* ------------------------------------------------------------------------ */

/**
*  \file
*  \brief Class bbtk::GConnectorController
*/


#include "GConnectorController.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif
namespace bbtk
{


	//=========================================================================
	GConnectorController::GConnectorController()
	{

	}

	//=========================================================================

	GConnectorController::~GConnectorController()
	{
	}

	//=========================================================================

	bool GConnectorController::OnMouseMove()
	{

		if (_view->getState() ==SELECTED)
		{
			_controller->GetManualViewBaseContour()->SetSelected(true);
		}
		
		if ( _vtkInteractorStyleBaseView!=NULL)
		{
			int X,Y;
			wxVTKRenderWindowInteractor *_wxVTKiren;
			_wxVTKiren= _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			_wxVTKiren->GetEventPosition( X , Y );

			if ( (_vtkInteractorStyleBaseView->GetInteractor()->GetControlKey()==0) &&(_vtkInteractorStyleBaseView->GetInteractor()->GetShiftKey()==0) )
			{
				_controller->MouseMove(X,Y);
			}

		}
		return true;
	}

	//=========================================================================

	bool GConnectorController::OnLeftButtonDown()
	{

		if ( _vtkInteractorStyleBaseView!=NULL )
		{
			int X,Y;
			wxVTKRenderWindowInteractor *wxVTKiren;
			wxVTKiren = _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			wxVTKiren->GetEventPosition(X,Y);

			_controller->SetKeyBoardMoving( false );
			_controller->MouseClickLeft(X,Y);

		}
		return true;
	}

	//=========================================================================

	bool GConnectorController::OnLeftButtonUp()
	{
		if( _vtkInteractorStyleBaseView!= NULL )
		{
			int X,Y;
			wxVTKRenderWindowInteractor *wxVTKiren;
			wxVTKiren = _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			wxVTKiren->GetEventPosition(X, Y);

			_controller->MouseReleaseLeft(X,Y);
			if(_controller->GetManualViewBaseContour()->GetSelected()==true)
			{
				_view->setState(SELECTED);
				_model->notifyObservers(getId(),ADD_TO_SELECTED);
			}

		}
		return true;

	}

	//=========================================================================

	bool GConnectorController::OnLeftDClick()
	{

		if ( _vtkInteractorStyleBaseView!=NULL )
		{
			int X,Y;
			wxVTKRenderWindowInteractor *wxVTKiren;
			wxVTKiren = _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			wxVTKiren->GetEventPosition(X,Y);

			_controller->MouseDLeft(X,Y);

		}
		return true;
	}

	//=========================================================================

	bool GConnectorController::OnRightButtonDown()
	{
		if( _vtkInteractorStyleBaseView!= NULL )
		{
			int X,Y;
			wxVTKRenderWindowInteractor *wxVTKiren;
			wxVTKiren = _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			wxVTKiren->GetEventPosition(X, Y);

			_controller->MouseClickRight(X,Y);

		}
		return true;
	}

	//=========================================================================

	bool GConnectorController::OnRightButtonUp()
	{
		return true;
	}

	//=========================================================================

	bool GConnectorController::OnMiddleButtonDown()
	{
		if ( _vtkInteractorStyleBaseView!=NULL )
		{
			int X, Y, Z=GPOSITION_Z;
			wxVTKRenderWindowInteractor *wxVTKiren;
			wxVTKiren = _vtkInteractorStyleBaseView->GetWxVtk3DBaseView()->GetWxVTKRenderWindowInteractor();
			wxVTKiren->GetEventPosition(X, Y);
			_controller->GetManualViewBaseContour()->InitMove( X, Y,Z);
		}
		return true;
	}
	//=========================================================================
	bool GConnectorController::OnMiddleButtonUp()
	{
		return true;
	}

	//=========================================================================

	manualConnectorContourController* GConnectorController::getManualContourController()
	{
		return _controller;
	}

	//=========================================================================

	void GConnectorController::setManualContourController(manualConnectorContourController* controller)
	{
		_controller = controller;
		_controller->SetVtkInteractorStyleBaseView(_vtkInteractorStyleBaseView);
	}

	//=========================================================================

	void GConnectorController::removeFromScene()
	{
		GConnectorModel *conMod = (GConnectorModel*)_model;
		conMod->disconnectConnection();

		_controller->SetEditable(false);
		_controller->DeleteContour();
	}

	//=========================================================================

	void GConnectorController::endContourCreation()
	{
		_controller->endContourCreation();
	}

	//=========================================================================

}  // EO namespace bbtk

// EOF

