/*
# ---------------------------------------------------------------------
#
# Copyright (c) CREATIS (Centre de Recherche en Acquisition et Traitement de l'Image 
#                        pour la Santé)
# Authors : Eduardo Davila, Frederic Cervenansky, Claire Mouton
#
#  This software is governed by the CeCILL-B license under French law and 
#  abiding by the rules of distribution of free software. You can  use, 
#  modify and/ or redistribute the software under the terms of the CeCILL-B 
#  license as circulated by CEA, CNRS and INRIA at the following URL 
#  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
#  or in the file LICENSE.txt.
#
#  As a counterpart to the access to the source code and  rights to copy,
#  modify and redistribute granted by the license, users are provided only
#  with a limited warranty  and the software's author,  the holder of the
#  economic rights,  and the successive licensors  have only  limited
#  liability. 
#
#  The fact that you are presently reading this means that you have had
#  knowledge of the CeCILL-B license and that you accept its terms.
# ------------------------------------------------------------------------  
*/

/*=========================================================================
Program:   bbtk
Module:    $RCSfile$
Language:  C++
Date:      $Date$
Version:   $Revision$
=========================================================================*/

/* ---------------------------------------------------------------------

* Copyright (c) CREATIS-LRMN (Centre de Recherche en Imagerie Medicale)
* Authors : Eduardo Davila, Laurent Guigues, Jean-Pierre Roux
*
*  This software is governed by the CeCILL-B license under French law and
*  abiding by the rules of distribution of free software. You can  use,
*  modify and/ or redistribute the software under the terms of the CeCILL-B
*  license as circulated by CEA, CNRS and INRIA at the following URL
*  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html
*  or in the file LICENSE.txt.
*
*  As a counterpart to the access to the source code and  rights to copy,
*  modify and redistribute granted by the license, users are provided only
*  with a limited warranty  and the software's author,  the holder of the
*  economic rights,  and the successive licensors  have only  limited
*  liability.
*
*  The fact that you are presently reading this means that you have had
*  knowledge of the CeCILL-B license and that you accept its terms.
* ------------------------------------------------------------------------ */



/**
*  \file
*  \brief Class bbtk::BlackBox : abstract black-box interface.
*/

/****
* Design and Developpement of BBTK GEditor
* Ricardo A Corredor J <ra.corredor67@uniandes.edu.co>
* RaC - 2010
****/

#ifndef __wxTabPanelsManager_h__
#define __wxTabPanelsManager_h__

#include <wx/aui/auibook.h>
#include <wx/panel.h>
#include <wx/string.h>
#include <map>
#include <iostream>
#include <creaWx.h>

#include "wxGEditorTabPanel.h"
#include "wxVtkSceneManager.h"
#include "bbtkwxGUIEditorGraphicBBS.h"

using namespace std;


namespace bbtk
{

	class wxVtkSceneManager;
	class wxGEditorTabPanel;
	class wxGUIEditorGraphicBBS;

	class wxTabPanelsManager : public wxEvtHandler
	{

	public:

		wxTabPanelsManager(wxGUIEditorGraphicBBS *parent);
		~wxTabPanelsManager();

		wxGUIEditorGraphicBBS* GetParentGUIEditorGraphicBBS() const;

		void addNewTab(wxString tabName=_T("new_tab"));
		wxAuiNotebook* getAuiNotebook();
		wxGEditorTabPanel* getActualTabPanel();

		void displayBlackBoxInfo(std::string packageName, std::string boxName);
		void updateStatusBar(std::string textStatus);

		std::string getActualDiagramBBS(bool wln=false);
		std::string getActualComplexBoxBBS();

		void editBlackBox(GBlackBoxModel *bbmodel);
		void deleteAllBoxesActualDiagram();
		void centerViewActualDiagram();
		void saveActualDiagram(std::string &content, const std::string &path); //DFCH
		void loadDiagram(ifstream &inputStream, const std::string &path); //DFCH

		void saveTempActualDiagram(const std::string &); //FCY
		void saveTempandUpdate(const std::string &);
		void loadTempDiagram(unsigned short un); //FCY
		unsigned short getUndoState(std::string &);
		unsigned short getRedoState(std::string &);
		bool isActualDiagramComplexBox();
		void setActualDiagramComplexBox(bool val);
		void addActualDiagramComplexInputPort(std::string portName);
		void addActualDiagramComplexOutputPort(std::string portName);
		void copySelectedBBoxesToComplexDiagram();
		int getNumActualSelectedObjects();

		void OnTabChanged(wxAuiNotebookEvent& event);

		// Event handler. Runs in the moment of closing but not closed yet (for that exists the CLOSED event, but not working at all)
		void OnTabClose(wxAuiNotebookEvent& event);

        void VerifyLastTabPanel();

        // Getters and Setters of current diagram
        void SetCbName(std::string cbName);
        void SetCbPackageName(std::string packagename);
        void SetAuthor(std::string author);
        void SetCategory(std::string category);
        void SetDescription(std::string description);
				void SetMessageKind(std::string kind);
				void SetMessageLevel(std::string level);
        std::string GetCbName();
        std::string GetCbPackageName();
        std::string GetAuthor();
        std::string GetDescription();
        std::string GetCategory();
				std::string GetMessageKind();
				std::string GetMessageLevel();

	    void SetNameTabPanel(wxString tabpanelname);
		std::string GetNameTabPanel();
	    std::string GetCurrentTabPanelPath( ); //DFCH
	    int  FindTab(std::string filename);
		bool TryToOpenScriptApplication(std::string packageName ,std::string boxType);

	private:

	// Private Attributes
		wxGUIEditorGraphicBBS           *_parent;
		map<int, wxGEditorTabPanel*>    _panels;
		wxGEditorTabPanel               *_actual;
		wxAuiNotebook                   *_notebook;
		int                             _lastId;

	protected:

	};


}
// namespace bbtk
#endif

